%global py_binary python3
%global _lto_cflags %{nil}

%undefine _auto_set_build_flags

Summary: Tool for Checkpoint/Restore in User-space
Name: criu
Version: 3.18
Release: 8%{?dist}
License: GPLv2
URL: http://criu.org/
Source0: https://github.com/checkpoint-restore/criu/archive/v%{version}/criu-%{version}.tar.gz
Source1: criu-tmpfiles.conf

Patch3000: criu.pc.patch
Patch3001: 0001-criu-3.18-add-support-for-loongarch64.patch


BuildRequires: gcc make systemd perl-interpreter
BuildRequires: libnet-devel asciidoctor perl-interpreter
BuildRequires: protobuf-devel protobuf-c-devel python3-devel libnl3-devel libcap-devel
BuildRequires: python3-pip python3-setuptools python3-wheel
BuildRequires: gnutls-devel

Recommends: tar

ExclusiveArch: x86_64 ppc64le aarch64 loongarch64

%description
criu is the user-space part of Checkpoint/Restore in User-space
(CRIU), a project to implement checkpoint/restore functionality for
Linux in user-space.

%package devel
Summary: Header files and libraries for %{name}
Requires: %{name} = %{version}-%{release}
Requires: %{name}-libs = %{version}-%{release}

%description devel
This package contains header files and libraries for %{name}.

%package libs
Summary: Libraries for %{name}
Requires: %{name} = %{version}-%{release}

%description libs
This package contains the libraries for %{name}

%package -n python3-%{name}
Summary: Python bindings for %{name}
Requires: python3-protobuf

%description -n python3-%{name}
python3-%{name} contains Python bindings for %{name}.

%package -n crit
Summary: CRIU image tool
Requires: python3-%{name} = %{version}-%{release}

%description -n crit
crit is a tool designed to decode CRIU binary dump files and show
their content in human-readable form.

%package -n criu-ns
Summary: Tool to run CRIU in different namespaces
Requires: %{name} = %{version}-%{release}

%description -n criu-ns
The purpose of the criu-ns wrapper script is to enable restoring a process
tree that might require a specific PID that is already used on the system.
This script can help to workaround the so called "PID mismatch" problem.

%prep
%autosetup -p1


%build
CFLAGS+=`echo %{optflags} | sed -e 's,-fstack-protector\S*,,g'` make V=1 WERROR=0 PREFIX=%{_prefix} RUNDIR=/run/criu PYTHON=python3
make docs V=1


%install
sed -e "s,--upgrade --force-reinstall,--disable-pip-version-check --progress-bar off --verbose,g" -i lib/Makefile
rm -f crit/pyproject.toml
make install-criu DESTDIR=%{buildroot} PREFIX=%{_prefix} LIBDIR=%{_libdir}
make install-lib DESTDIR=%{buildroot} PREFIX=%{_prefix} LIBDIR=%{_libdir} PYTHON=python3
make install-man DESTDIR=%{buildroot} PREFIX=%{_prefix} LIBDIR=%{_libdir}

mkdir -p %{buildroot}%{_tmpfilesdir}
install -m0644 %{SOURCE1} %{buildroot}%{_tmpfilesdir}/%{name}.conf
install -d -m0755 %{buildroot}/run/%{name}/

rm -f %{buildroot}%{_mandir}/man1/compel.1
rm -f %{buildroot}%{_mandir}/man1/amdgpu_plugin.1
rm -f %{buildroot}%{_libdir}/libcriu.a

%files
%license COPYING
%doc README.md
%{_sbindir}/%{name}
%{_libexecdir}/%{name}
%dir /run/%{name}
%{_tmpfilesdir}/%{name}.conf
%{_mandir}/man8/criu.8*

%files devel
%{_includedir}/criu
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files libs
%{_libdir}/*.so.*

%files -n python3-%{name}
%{python3_sitelib}/pycriu/*
%{python3_sitelib}/crit-%{version}.dist-info/

%files -n crit
%{_bindir}/crit
%{_mandir}/man1/crit.1*

%files -n criu-ns
%{_sbindir}/criu-ns
%{_mandir}/man1/criu-ns.1*

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.18-8
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.18-7
- Rebuilt for loongarch release

* Wed Jun 5 2024 Pengda Dou <doupengda@loongson.cn> - 3.18-6
- [Type] other
- [DESC] add support for loongarch64

* Wed Sep 20 2023 Miaojun Dong <zoedong@tencent.com> - 3.18-5
- Rebuild for protobuf-24.2

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.18-4
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.18-3
- Rebuilt for OpenCloudOS Stream 23.09

* Thu Sep 07 2023 cunshunxia@tencent.com - 3.18-2
- Rebuilt for protobuf 3.21.12

* Fri Jun 30 2023 kianli <kianli@tencent.com> - 3.18-1
- Upgrade to 3.18

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.17.1-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.17.1-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Mar 08 2023 cunshunxia <cunshunxia@tencent.com> - 3.17.1-1
- initial build
